<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>command not found</source>
        <translation>команда не найдена</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Operation successfully completed.</source>
        <translation>Операция успешно завершена.</translation>
    </message>
    <message>
        <source>An error has occurs during the operation.</source>
        <translation>Во время операции произошла ошибка.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_new call.</source>
        <translation>Произошла ошибка во время вызова ped_disk_new.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_get_partition call.</source>
        <translation>Произошла ошибка во время вызова ped_disk_get_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_new call.</source>
        <translation>Произошла ошибка во время вызова ped_partition_call.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_add_partition call.</source>
        <translation>Произошла ошибка во время вызова ped_disk_add_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_system call.</source>
        <translation>Произошла ошибка во время вызова ped_partition_set_system.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_flag call.</source>
        <translation>Произошла ошибка во время вызова ped_partition_set_flag.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_delete_partition call.</source>
        <translation>Произошла ошибка во время вызова ped_disk_delete_partition.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>A program that create NTFS partitions.</source>
        <translation>Программа, создающая раздел NTFS.</translation>
    </message>
    <message>
        <source>A program that resize NTFS partitions.</source>
        <translation>Программа, изменяющая размер раздела NTFS.</translation>
    </message>
    <message>
        <source>A program that create EXT3 partitions.</source>
        <translation>Программа, создающая раздел EXT3.</translation>
    </message>
    <message>
        <source>A program that create JFS partitions.</source>
        <translation>Программа, создающая раздел JFS.</translation>
    </message>
    <message>
        <source>A program that create XFS partitions.</source>
        <translation>Программа, создающая раздел XFS.</translation>
    </message>
    <message>
        <source>Cannot read /proc/partitions, QTParted cannot be used!.
Please use a kernel with /proc/partitions support.</source>
        <translation type="obsolete">Невозможно прочитать /proc/partitions, невозможно использоать QTParted!
Пожалуйста, используйте ядро с поддежкой /proc/partitions.</translation>
    </message>
    <message>
        <source>Cannot get parted version.</source>
        <translation>Невозможно определить версию parted.</translation>
    </message>
    <message>
        <source>Parted is too old:
- installed parted version: %1.%2.%3
- required parted version: %4.%5.%6 (or better)

Parted homepage: http://www.gnu.org/software/parted/</source>
        <translation>Слишком старая версия parted:
- установленная версия parted: %1.%2.%3
- требуемая версия parted: %4.%5.%6 (или старше)

Домашня страница parted: http://www.gnu.org/software/parted/</translation>
    </message>
    <message>
        <source>Cannot umount partition device: %1.Please do it by hand first to commit the changes!</source>
        <translation>Не могу отмонтировать раздел устройства: %1. Пожалуйста, сделайте это вручную для совершения изменений!</translation>
    </message>
    <message>
        <source>Utility for mount a filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Utility for umount a filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Utility for grow a xfs filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_ActionList</name>
    <message>
        <source>Getting info about partition %1.</source>
        <translation>Получение информации о разделе %1.</translation>
    </message>
    <message>
        <source>Creating partition.</source>
        <translation>Создание раздела.</translation>
    </message>
    <message>
        <source>Preparation for removing a partition.</source>
        <translation>Подготовка к удалению раздела.</translation>
    </message>
    <message>
        <source>Removing a partition.</source>
        <translation>Удаление раздела.</translation>
    </message>
    <message>
        <source>Preparation for resizing a partition.</source>
        <translation>Подготовка к изменению размера раздела.</translation>
    </message>
    <message>
        <source>Resizing a partition.</source>
        <translation>Изменение размера раздела.</translation>
    </message>
    <message>
        <source>Preparation for activating a partition.</source>
        <translation>Подготовка к активации раздела.</translation>
    </message>
    <message>
        <source>Activating a partition.</source>
        <translation>Делаю раздел активным.</translation>
    </message>
    <message>
        <source>Preparation for formatting a partition.</source>
        <translation>Подготовка к форматированию раздела.</translation>
    </message>
    <message>
        <source>Formatting a partition.</source>
        <translation>Форматирование раздела.</translation>
    </message>
    <message>
        <source>Rescan of the disk.</source>
        <translation>Повторное сканирование диска.</translation>
    </message>
    <message>
        <source>Preparation for moving a partition.</source>
        <translation>Подготовка к перемещению раздела.</translation>
    </message>
    <message>
        <source>Moving a partition.</source>
        <translation>Перемещение раздела.</translation>
    </message>
    <message>
        <source>All operations completed.</source>
        <translation>Все операции завершены.</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_new!</source>
        <translation>Критическая ошибка во время ped_disk_new!</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_duplicate!</source>
        <translation>Критическая ошибка во время ped_disk_duplicate!</translation>
    </message>
    <message>
        <source>Preparation for hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hiding a partition.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_DriveList</name>
    <message>
        <source>No device found. Maybe you&apos;re not using root user?</source>
        <translation>Устройство не найдено. Возможно вы не являетесь пользователем root?</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Диски</translation>
    </message>
</context>
<context>
    <name>QP_FSExt3</name>
    <message>
        <source>Writing superblocks and filesystem.</source>
        <translation>Запись суперблока и файловой системы.</translation>
    </message>
    <message>
        <source>Writing inode tables.</source>
        <translation>Запись таблицы i-узлов.</translation>
    </message>
    <message>
        <source>There was a problem with mkfs.ext3.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSJfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не могу расширить раздел, если устройство занято</translation>
    </message>
</context>
<context>
    <name>QP_FSNtfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не могу расширить раздел, если устройство занято</translation>
    </message>
    <message>
        <source>Resizing in progress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syncing device.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSReiserFS</name>
    <message>
        <source>No label</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_FSXfs</name>
    <message>
        <source>There was a problem with mkfs.xfs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="unfinished">Не могу расширить раздел, если устройство занято</translation>
    </message>
    <message>
        <source>Error during xfs_grow.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_LibParted</name>
    <message>
        <source>The partition is mounted.</source>
        <translation>Раздел подмонтирован.</translation>
    </message>
    <message>
        <source>Can&apos;t move extended partitions.</source>
        <translation>Не могу перемещать расширенные разделы.</translation>
    </message>
    <message>
        <source>Can&apos;t move a partition onto itself. Try using resize, perhaps?</source>
        <translation>Не могу переместить раздел в самого себя. Попытаться сделать изменение размера?</translation>
    </message>
    <message>
        <source>An error happen during ped_geometry_init call.</source>
        <translation>Произошла ошибка во время вызова ped_geometry_init.</translation>
    </message>
    <message>
        <source>An error happen during ped_disk_set_partition_geom call.</source>
        <translation>Произошла ошибка во время вызова ped_disk_set_partition_geom.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_open call.</source>
        <translation>Произошла ошибка во время вызова ped_file_system_open.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_resize call.</source>
        <translation>Произошла ошибка во время вызова ped_file_system_resize.</translation>
    </message>
    <message>
        <source>Scanning all disk partitions.</source>
        <translation>Сканирование всех разделов диска.</translation>
    </message>
    <message>
        <source>Partition %s is being used.</source>
        <translation>Раздел %s используется в данный момент.</translation>
    </message>
    <message>
        <source>Cannot change the active status on this partition</source>
        <translation>Невозможно изменить статус активного раздела</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during set_system, please report it!</source>
        <translation>В QTParted была найдена ошибка во время set_system, пожалуйста сообщите об этом!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during ped_file_system_type_get, please report it!</source>
        <translation>В QTParted была найдена ошибка во время ped_file_system_type_get, пожалуйста сообщите об этом!</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Это виртуальный раздел. Вы не можете его изменить: используйте отмену.</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;resize&quot; scan, please report it!</source>
        <translation>В QTParted была найдена ошибка во время сканирования &quot;resize&quot;, пожалуйста сообщите об этом!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;mkfs&quot; scan, please report it!</source>
        <translation>В QTParted была найдена ошибка во время сканирования &quot;mkfs&quot;, пожалуйста сообщите об этом!</translation>
    </message>
    <message>
        <source>Error committing device.
This can happen when a device is mounted in the disk.
Try to unmount all partitions on this disk.
Please read the FAQ for this kind of error!</source>
        <translation>Ошибка работы с устройством.
Это могло случиться в том случае, если раздел подмонтирован.
Попробуйте отмонтировать все разделы диска.
Пожалуйста, прочтите FAQ для такого рода ошибок!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;move&quot; scan, please report it!</source>
        <translation>В QTParted была найдена ошибка во время сканирования &quot;move&quot;, пожалуйста сообщите об этом!</translation>
    </message>
    <message>
        <source>Cannot change the hidden status on this partition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_MainWindow</name>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Quit from the application</source>
        <translation>Выход из программы</translation>
    </message>
    <message>
        <source>&amp;Property</source>
        <translation>C&amp;войства</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <source>Property of the selected partition</source>
        <translation>Свойства выделенного раздела</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <source>Create a new partition</source>
        <translation>Создать новый раздел</translation>
    </message>
    <message>
        <source>&amp;Resize</source>
        <translation>Изменить &amp;размер</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <source>Resize a partition</source>
        <translation>Изменить размер раздела</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Переместить</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Переместить</translation>
    </message>
    <message>
        <source>Move a partition</source>
        <translation>Переместить раздел</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>У&amp;далить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Delete a new partition</source>
        <translation>Удалить новый раздел</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Operations</source>
        <translation>&amp;Операции</translation>
    </message>
    <message>
        <source>this is a %1 partition
it start at: %2 and end at: %3
it can grow left: %4 and right: %5
the filesystem is: %6</source>
        <translation type="unfinished">Это %1 раздел.
он начинается с %2 и заканчивается %3
он может быть увеличен влево на %4 и вправо на %5
файловая система: %6</translation>
    </message>
    <message>
        <source>Enter &lt;b&gt;What&apos;s This&lt;/b&gt; modeIt enables the user to ask for help about widgets on the screen.</source>
        <translation>Для получения справки о виджетах на экране, вы можете воспользоваться пунктом меню &lt;b&gt;What&apos;s This&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>Что э&amp;то</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Что это</translation>
    </message>
    <message>
        <source>About QT</source>
        <translation>О QT</translation>
    </message>
    <message>
        <source>Information about QT</source>
        <translation>Инфомация о QT</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>About &amp;QTParted</source>
        <translation>О &amp;QTParted</translation>
    </message>
    <message>
        <source>About QTParted</source>
        <translation>О QTParted</translation>
    </message>
    <message>
        <source>Information about QTParted</source>
        <translation>Инфомация о QTParted</translation>
    </message>
    <message>
        <source>About Q&amp;T</source>
        <translation>О Q&amp;T</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О</translation>
    </message>
    <message>
        <source>An internal error happened during partition scan.
This means that you cannot resize or move this partition.</source>
        <translation>Во время сканирования раздела произошла внутренняя ошибка.
Это означает, что вы не можете переместить раздел, а также изменить его размер.</translation>
    </message>
    <message>
        <source>Getting devices</source>
        <translation>Поиск устройств</translation>
    </message>
    <message>
        <source>load user settings</source>
        <translation>загрузка пользовательских установок</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Готово</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>О&amp;тмена</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Undo last operation</source>
        <translation>Отмена последней операции</translation>
    </message>
    <message>
        <source>&amp;Commit</source>
        <translation>П&amp;рименить</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>Commit all operations</source>
        <translation>Применить все операции</translation>
    </message>
    <message>
        <source>&amp;Configuration...</source>
        <translation>&amp;Конфигурация...</translation>
    </message>
    <message>
        <source>Configuration of QTParted</source>
        <translation>Конфигурация QTParted</translation>
    </message>
    <message>
        <source>Open the configuration dialog</source>
        <translation>Открыть конфигурационный диалог</translation>
    </message>
    <message>
        <source>Set Active...</source>
        <translation>Сделать активным...</translation>
    </message>
    <message>
        <source>&amp;Disks</source>
        <translation>&amp;Диски</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Опции</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Это виртуальный раздел. Вы не можете его изменить: используйте отмену.</translation>
    </message>
    <message>
        <source>primary</source>
        <translation>основной</translation>
    </message>
    <message>
        <source>logical</source>
        <translation>логический</translation>
    </message>
    <message>
        <source>extended</source>
        <translation>расширенный</translation>
    </message>
    <message>
        <source>(No Active on Drive)</source>
        <translation>(Нет активных разделов на диске)</translation>
    </message>
    <message>
        <source>Currently active partition: %1
Change active partition to: %2

Are you sure you want to change the active partition?</source>
        <translation>В данный момент является активным раздел: %1
Сделать активным раздел: %2

Вы уверены, что хотите изменить активный раздел?</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation>&amp;Форматировать</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Форматировать</translation>
    </message>
    <message>
        <source>Format a new partition</source>
        <translation>Форматировать новый раздел</translation>
    </message>
    <message>
        <source>&amp;Device property</source>
        <translation>Свойства &amp;устройства</translation>
    </message>
    <message>
        <source>&amp;Make a new Partition Table</source>
        <translation>&amp;Создать новую таблицу разделов</translation>
    </message>
    <message>
        <source>This will make the partition table</source>
        <translation>Это создаст таблицу разделов</translation>
    </message>
    <message>
        <source>You&apos;re going to loose all partition data! Are you sure? :)</source>
        <translation>Вы потеряете всю информацию в разделе! Вы уверены? :)</translation>
    </message>
    <message>
        <source>detected</source>
        <translation>обнаружено</translation>
    </message>
    <message>
        <source>none</source>
        <translation>нет</translation>
    </message>
    <message>
        <source>You&apos;re going to make a new partition table. Are you sure?
All data will be lost!</source>
        <translation>Вы создатите новую таблицу разделов. Вы уверены?
Все данные будут потеряны!</translation>
    </message>
    <message>
        <source>It was not possible to make a new partition table.</source>
        <translation>Не возможно создать новую таблицу разделов.</translation>
    </message>
    <message>
        <source>Device status: readonly.</source>
        <translation>Статус устройства: только чтение.</translation>
    </message>
    <message>
        <source>Device status: busy.</source>
        <translation>Статус устройства: занято.</translation>
    </message>
    <message>
        <source>Device status: available.</source>
        <translation>Статус устройства: свободно.</translation>
    </message>
    <message>
        <source>You&apos;re commiting all changes. Warning, you can lost data!
Make sure also that you&apos;re not commiting a busy device...
In other word PLEASE UMOUNT ALL PARTITIONS before commiting changes!</source>
        <translation>Вы применяете все изменения. Вы можете потерять данные!
Убедитесь, что вы не будуте использовать занятое устройство...
Другими словами, ПОЖАЛУЙСТА, ОТМОНТИРУЙТЕ ВСЕ РАЗДЕЛЫ перед из изменением!</translation>
    </message>
    <message>
        <source>&amp;Device</source>
        <translation>&amp;Устройство</translation>
    </message>
    <message>
        <source>See the property of this disk device</source>
        <translation>Смотри свойства этого диска</translation>
    </message>
    <message>
        <source>Some information about the disk device</source>
        <translation>Краткая информация о диске</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_NavView</name>
    <message>
        <source>The following drives have been detected:</source>
        <translation>Были обнаружены следующие накопители:</translation>
    </message>
    <message>
        <source>Drive Info</source>
        <translation>Информация о диске</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Устройство:</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation>Модель:</translation>
    </message>
    <message>
        <source>Capacity (Mb):</source>
        <translation>Емкость (MB):</translation>
    </message>
    <message>
        <source>Length sectors:</source>
        <translation>Длина секторов:</translation>
    </message>
    <message>
        <source>No Drive Selected</source>
        <translation>Не Выбрано Устройство</translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Статус:</translation>
    </message>
    <message>
        <source>readonly.</source>
        <translation>только чтение.</translation>
    </message>
    <message>
        <source>busy.</source>
        <translation>занято.</translation>
    </message>
    <message>
        <source>available.</source>
        <translation>свободно.</translation>
    </message>
</context>
<context>
    <name>QP_PartInfo</name>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>Это виртуальный раздел. Вы не можете его изменить: используйте отмену.</translation>
    </message>
    <message>
        <source>Bug during mkfs! Cannot format virtual partitions!</source>
        <translation>Ошибка mkfs! Не могу форматировать виртуальный раздел!</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="obsolete">Не могу расширить раздел, если устройство занято</translation>
    </message>
</context>
<context>
    <name>QP_RealListView</name>
    <message>
        <source>Number</source>
        <translation>Номер</translation>
    </message>
    <message>
        <source>Partition</source>
        <translation>Раздел</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начало</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Конец</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Used space</source>
        <translation>Заполнено</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Активный</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Не определен</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Пустой</translation>
    </message>
    <message>
        <source>Partition table</source>
        <translation>Таблица разделов</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QP_UIConfig</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Конфигурация</translation>
    </message>
    <message>
        <source>QTParted &amp;layout</source>
        <translation>QTParted &amp;формат</translation>
    </message>
    <message>
        <source>Chart and ListBox</source>
        <translation>Диаграмма и список</translation>
    </message>
    <message>
        <source>Only Chart</source>
        <translation>Только диаграмма</translation>
    </message>
    <message>
        <source>Only ListBox</source>
        <translation>Только список</translation>
    </message>
    <message>
        <source>&amp;External Tools</source>
        <translation>&amp;Внешние средства</translation>
    </message>
    <message>
        <source>&amp;Full executable path</source>
        <translation>&amp;Полный путь</translation>
    </message>
</context>
<context>
    <name>QP_UICreate</name>
    <message>
        <source>Create partition</source>
        <translation>Создать раздел</translation>
    </message>
    <message>
        <source>&amp;Size:</source>
        <translation>&amp;Размер:</translation>
    </message>
    <message>
        <source>Create &amp;as:</source>
        <translation>Создать &amp;как:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Метка:</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Тип &amp;раздела:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <source>&amp;Beginning of unallocated space</source>
        <translation>В &amp;начале пустого раздела</translation>
    </message>
    <message>
        <source>&amp;End of unallocated space</source>
        <translation>В &amp;конце пустого раздела</translation>
    </message>
    <message>
        <source>Pe&amp;rcent of unallocated space:</source>
        <translation>&amp;Процентов от пустого раздела:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Нет</translation>
    </message>
</context>
<context>
    <name>QP_UIDeviceProperty</name>
    <message>
        <source>Device property</source>
        <translation>Свойства устройства</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Короткое имя устройства</translation>
    </message>
    <message>
        <source>Device long name</source>
        <translation>Длинное имя устройства</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>QP_UIFormat</name>
    <message>
        <source>Format partition</source>
        <translation>Форматировать раздел</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>Тип &amp;раздела:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Метка:</translation>
    </message>
</context>
<context>
    <name>QP_UIProgress</name>
    <message>
        <source>Progress</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Прогресс:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>Current operation:</source>
        <translation>Текущая операция:</translation>
    </message>
    <message>
        <source>Time Left:</source>
        <translation>Оставшееся время:</translation>
    </message>
</context>
<context>
    <name>QP_UIResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Изменение размера раздела</translation>
    </message>
    <message>
        <source>Minimum Size:</source>
        <translation>Минимальный размер:</translation>
    </message>
    <message>
        <source>Free Space &amp;Before:</source>
        <translation>Пустое место в &amp;начале:</translation>
    </message>
    <message>
        <source>New Size:</source>
        <translation>Новый размер:</translation>
    </message>
    <message>
        <source>Free Space &amp;After:</source>
        <translation>Пустое место в &amp;конце:</translation>
    </message>
    <message>
        <source>It is recommended to backup your data before do this operation!</source>
        <translation>Рекомендуется создать резервную копию вашей информации перед тем как сделать даную операцию!</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Нет</translation>
    </message>
</context>
<context>
    <name>QP_dlgAbout</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Да</translation>
    </message>
</context>
<context>
    <name>QP_dlgCreate</name>
    <message>
        <source>This filesystem cannot be greater of %1</source>
        <translation>Эта файловая система не может быть большей, чем %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgDevProperty</name>
    <message>
        <source>Devfs is enabled.</source>
        <translation>Включена поддержка devfs.</translation>
    </message>
    <message>
        <source>Devfs is disabled.</source>
        <translation>Отключенна поддержка devfs.</translation>
    </message>
    <message>
        <source>Partition table: %1</source>
        <translation>Таблица раздела: %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgProgress</name>
    <message>
        <source>Initializing</source>
        <translation>Инициализация</translation>
    </message>
    <message>
        <source>Time Left: %1</source>
        <translation>Оставшееся время: %1</translation>
    </message>
    <message>
        <source>Operation: %1 of %2.
Current operation: %3</source>
        <translation>Операция: %1 из %2.
Текущая операция: %3</translation>
    </message>
    <message>
        <source>Operations completed sucessfully.</source>
        <translation>Операции завершены успешно.</translation>
    </message>
</context>
<context>
    <name>QP_dlgResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Изменить размер раздела</translation>
    </message>
    <message>
        <source>Minimum Size: %1 MB</source>
        <translation>Минимальный размер: %1 MB</translation>
    </message>
    <message>
        <source>Move partition</source>
        <translation>Переместить раздел</translation>
    </message>
</context>
</TS>
